Branch: master

32640119 2016-11-05 10:39:16 François Andriot
RPM packaging: update build scripts
M redhat/Makefile.r14
M redhat/build/get_rpm_package_name.sh
diff --git a/redhat/Makefile.r14 b/redhat/Makefile.r14
index 16782ac..f235364 100644
--- a/redhat/Makefile.r14
+++ b/redhat/Makefile.r14
@@ -106,7 +106,7 @@
 tdegraphics:	tdebase poppler cmake lcms
 	$(call buildpkg,main/tdegraphics)
 
-tdelibs:	tqt3 tqtinterface arts dbus-tqt dbus-1-tqt cmake avahi-tqt fileshareset trinity-filesystem libart_lgpl
+tdelibs:	tqt3 tqtinterface arts dbus-tqt dbus-1-tqt cmake avahi-tqt fileshareset trinity-filesystem libart_lgpl file
 	$(call buildpkg,main/tdelibs)
 
 tdemultimedia:	tdebase akode
@@ -164,6 +164,12 @@
 	$(call buildpkg,3rdparty/esound)
 endif
 
+file:
+# Build on CentOS 5
+ifneq ($(wildcard /boot/vmlinuz*.el5*),)
+	$(call buildpkg,3rdparty/file)
+endif
+
 gnuchess:
 # Build on CentOS 5, CentOS 7
 ifneq ($(wildcard /boot/vmlinuz*.el5* /boot/vmlinuz*.el7*),)
diff --git a/openbsd/dependencies/tqt3/pkg/PLIST-main~ b/openbsd/dependencies/tqt3/pkg/PLIST-main~
deleted file mode 100644
index 76a8131..0000000
--- a/openbsd/dependencies/tqt3/pkg/PLIST-main~
+++ /dev/null
@@ -1,2612 +0,0 @@
-@comment $OpenBSD$
-%%SHARED%%
-@bin bin/maketqpf
-@bin bin/msg2tqm
-@bin bin/tqassistant
-@bin bin/tqdesigner
-@bin bin/tqembed
-@bin bin/tqlinguist
-@bin bin/tqlrelease
-@bin bin/tqlupdate
-@bin bin/tqm2ts
-@bin bin/tqmake
-@bin bin/tqmoc
-bin/tqt20fix
-@bin bin/tqtconfig
-@bin bin/tqtconv2ui
-@bin bin/tqtcreatecw
-bin/tqtfindtr
-@bin bin/tqtmergetr
-bin/tqtrename140
-@bin bin/tquic
-@bin bin/tqvfb
-include/tqt3/
-include/tqt3/ntq1xcompatibility.h
-include/tqt3/ntqabstractlayout.h
-include/tqt3/ntqaccel.h
-include/tqt3/ntqaccessible.h
-include/tqt3/ntqaction.h
-include/tqt3/ntqapp.h
-include/tqt3/ntqapplication.h
-include/tqt3/ntqarray.h
-include/tqt3/ntqasciicache.h
-include/tqt3/ntqasciidict.h
-include/tqt3/ntqassistantclient.h
-include/tqt3/ntqasyncimageio.h
-include/tqt3/ntqasyncio.h
-include/tqt3/ntqbig5codec.h
-include/tqt3/ntqbitarray.h
-include/tqt3/ntqbitarry.h
-include/tqt3/ntqbitmap.h
-include/tqt3/ntqbrush.h
-include/tqt3/ntqbttngrp.h
-include/tqt3/ntqbuffer.h
-include/tqt3/ntqbutton.h
-include/tqt3/ntqbuttongroup.h
-include/tqt3/ntqcache.h
-include/tqt3/ntqcanvas.h
-include/tqt3/ntqcdestyle.h
-include/tqt3/ntqcheckbox.h
-include/tqt3/ntqchkbox.h
-include/tqt3/ntqcleanuphandler.h
-include/tqt3/ntqclipboard.h
-include/tqt3/ntqclipbrd.h
-include/tqt3/ntqcollect.h
-include/tqt3/ntqcollection.h
-include/tqt3/ntqcolor.h
-include/tqt3/ntqcolordialog.h
-include/tqt3/ntqcombo.h
-include/tqt3/ntqcombobox.h
-include/tqt3/ntqcommonstyle.h
-include/tqt3/ntqcompactstyle.h
-include/tqt3/ntqconfig.h
-include/tqt3/ntqconnect.h
-include/tqt3/ntqconnection.h
-include/tqt3/ntqcstring.h
-include/tqt3/ntqcursor.h
-include/tqt3/ntqdatabrowser.h
-include/tqt3/ntqdatastream.h
-include/tqt3/ntqdatatable.h
-include/tqt3/ntqdataview.h
-include/tqt3/ntqdatetime.h
-include/tqt3/ntqdatetimeedit.h
-include/tqt3/ntqdatetm.h
-include/tqt3/ntqdeepcopy.h
-include/tqt3/ntqdesktopwidget.h
-include/tqt3/ntqdial.h
-include/tqt3/ntqdialog.h
-include/tqt3/ntqdict.h
-include/tqt3/ntqdir.h
-include/tqt3/ntqdns.h
-include/tqt3/ntqdockarea.h
-include/tqt3/ntqdockwindow.h
-include/tqt3/ntqdom.h
-include/tqt3/ntqdragobject.h
-include/tqt3/ntqdrawutil.h
-include/tqt3/ntqdrawutl.h
-include/tqt3/ntqdropsite.h
-include/tqt3/ntqdstream.h
-include/tqt3/ntqeditorfactory.h
-include/tqt3/ntqerrormessage.h
-include/tqt3/ntqeucjpcodec.h
-include/tqt3/ntqeuckrcodec.h
-include/tqt3/ntqevent.h
-include/tqt3/ntqeventloop.h
-include/tqt3/ntqfeatures.h
-include/tqt3/ntqfile.h
-include/tqt3/ntqfiledef.h
-include/tqt3/ntqfiledialog.h
-include/tqt3/ntqfiledlg.h
-include/tqt3/ntqfileinf.h
-include/tqt3/ntqfileinfo.h
-include/tqt3/ntqfocusdata.h
-include/tqt3/ntqfont.h
-include/tqt3/ntqfontdatabase.h
-include/tqt3/ntqfontdialog.h
-include/tqt3/ntqfontinf.h
-include/tqt3/ntqfontinfo.h
-include/tqt3/ntqfontmet.h
-include/tqt3/ntqfontmetrics.h
-include/tqt3/ntqframe.h
-include/tqt3/ntqftp.h
-include/tqt3/ntqgarray.h
-include/tqt3/ntqgb18030codec.h
-include/tqt3/ntqgbkcodec.h
-include/tqt3/ntqgcache.h
-include/tqt3/ntqgdict.h
-include/tqt3/ntqgeneric.h
-include/tqt3/ntqgif.h
-include/tqt3/ntqgl.h
-include/tqt3/ntqglcolormap.h
-include/tqt3/ntqglist.h
-include/tqt3/ntqglobal.h
-include/tqt3/ntqgplugin.h
-include/tqt3/ntqgrid.h
-include/tqt3/ntqgridview.h
-include/tqt3/ntqgroupbox.h
-include/tqt3/ntqgrpbox.h
-include/tqt3/ntqguardedptr.h
-include/tqt3/ntqgvector.h
-include/tqt3/ntqhbox.h
-include/tqt3/ntqhbuttongroup.h
-include/tqt3/ntqheader.h
-include/tqt3/ntqhgroupbox.h
-include/tqt3/ntqhostaddress.h
-include/tqt3/ntqhttp.h
-include/tqt3/ntqiconset.h
-include/tqt3/ntqiconview.h
-include/tqt3/ntqimage.h
-include/tqt3/ntqimageformatplugin.h
-include/tqt3/ntqinputcontext.h
-include/tqt3/ntqinputcontextfactory.h
-include/tqt3/ntqinputcontextplugin.h
-include/tqt3/ntqinputdialog.h
-include/tqt3/ntqintcach.h
-include/tqt3/ntqintcache.h
-include/tqt3/ntqintdict.h
-include/tqt3/ntqinterlacestyle.h
-include/tqt3/ntqiodev.h
-include/tqt3/ntqiodevice.h
-include/tqt3/ntqjiscodec.h
-include/tqt3/ntqjpegio.h
-include/tqt3/ntqjpunicode.h
-include/tqt3/ntqkeycode.h
-include/tqt3/ntqkeysequence.h
-include/tqt3/ntqlabel.h
-include/tqt3/ntqlayout.h
-include/tqt3/ntqlcdnum.h
-include/tqt3/ntqlcdnumber.h
-include/tqt3/ntqlibrary.h
-include/tqt3/ntqlined.h
-include/tqt3/ntqlineedit.h
-include/tqt3/ntqlist.h
-include/tqt3/ntqlistbox.h
-include/tqt3/ntqlistview.h
-include/tqt3/ntqlocale.h
-include/tqt3/ntqlocalfs.h
-include/tqt3/ntqmainwindow.h
-include/tqt3/ntqmap.h
-include/tqt3/ntqmemarray.h
-include/tqt3/ntqmenubar.h
-include/tqt3/ntqmenudata.h
-include/tqt3/ntqmenudta.h
-include/tqt3/ntqmessagebox.h
-include/tqt3/ntqmetaobj.h
-include/tqt3/ntqmetaobject.h
-include/tqt3/ntqmime.h
-include/tqt3/ntqmlined.h
-include/tqt3/ntqmngio.h
-include/tqt3/ntqmodules.h
-include/tqt3/ntqmotifplusstyle.h
-include/tqt3/ntqmotifstyle.h
-include/tqt3/ntqmovie.h
-include/tqt3/ntqmsgbox.h
-include/tqt3/ntqmultilinedit.h
-include/tqt3/ntqmultilineedit.h
-include/tqt3/ntqmutex.h
-include/tqt3/ntqnamespace.h
-include/tqt3/ntqnetwork.h
-include/tqt3/ntqnetworkprotocol.h
-include/tqt3/ntqnp.h
-include/tqt3/ntqobjcoll.h
-include/tqt3/ntqobjdefs.h
-include/tqt3/ntqobject.h
-include/tqt3/ntqobjectcleanuphandler.h
-include/tqt3/ntqobjectdefs.h
-include/tqt3/ntqobjectdict.h
-include/tqt3/ntqobjectlist.h
-include/tqt3/ntqpaintd.h
-include/tqt3/ntqpaintdc.h
-include/tqt3/ntqpaintdevice.h
-include/tqt3/ntqpaintdevicedefs.h
-include/tqt3/ntqpaintdevicemetrics.h
-include/tqt3/ntqpainter.h
 ** Diff limit reached (max: 250 lines) **
2bf39e95 2016-11-05 10:40:03 François Andriot
RPM packaging: fix koffice development libraries installation
M redhat/applications/koffice/koffice-14.0.0.spec
 ** Diff limit reached (max: 250 lines) **
diff --git a/redhat/build/get_rpm_package_name.sh b/redhat/build/get_rpm_package_name.sh
index e84d99d..ca8303a 100755
--- a/redhat/build/get_rpm_package_name.sh
+++ b/redhat/build/get_rpm_package_name.sh
@@ -75,8 +75,8 @@
 if [ -n "${DEVEL}" ]; then
   # Check if development package is required.
   case "${PKGCATEGORY}" in
-    # Applications do NOT have 'devel' package, except K3B.
-    "applications") if [ "${PKGNAME}" != "k3b" ]; then exit 0; fi;;
+    # Applications do NOT have 'devel' package, except K3B, Koffice.
+    "applications") if [ "${PKGNAME}" != "k3b" ] && [ "${PKGNAME}" != "koffice" ]; then exit 0; fi;;
     # Extras packages do NOT have 'devel' package, except Akode
     "extras") if [ "${PKGNAME}" != "akode" ] && [ "${PKGNAME}" != "hk_classes" ]; then exit 0; fi;;
   esac
42a9c986 2016-11-05 10:39:39 François Andriot
Openbsd: remove temporary useless file
R openbsd/dependencies/tqt3/pkg/PLIST-main~